/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { S3ObjectMetaInformation } from '../models/S3ObjectMetaInformation';

import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';

export class ObjectService {

    /**
     * Get the metadata of the objects in the bucket
     * Get the metadata of the objects in the bucket.
     *
     * If the user has permissions for the bucket and uses the `file_prefix` parameter, it will be concatenated with the
     * allowed prefix from the permission.
     *
     * Permission "bucket:read" required if the current user has access to the bucket,
     * otherwise "bucket:read_any" required.
     * @param bucketName Name of bucket
     * @param filePrefix Get only objects with the specified prefix.
     * @returns S3ObjectMetaInformation Successful Response
     * @throws ApiError
     */
    public static objectGetBucketObjects(
        bucketName: string,
        filePrefix?: string,
    ): CancelablePromise<Array<S3ObjectMetaInformation>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets/{bucket_name}/objects',
            path: {
                'bucket_name': bucketName,
            },
            query: {
                'file_prefix': filePrefix,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get the metadata about a specific object
     * Get the metadata of a specific object in a bucket.
     *
     * Permission "bucket:read" required if the current user has access to the bucket,
     * otherwise "bucket:read_any" required.
     * @param objectPath
     * @param bucketName Name of bucket
     * @returns S3ObjectMetaInformation Successful Response
     * @throws ApiError
     */
    public static objectGetBucketObject(
        objectPath: string,
        bucketName: string,
    ): CancelablePromise<S3ObjectMetaInformation> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets/{bucket_name}/objects/{object_path}',
            path: {
                'object_path': objectPath,
                'bucket_name': bucketName,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

}
