/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { Status } from '../models/Status';
import type { WorkflowVersionFull } from '../models/WorkflowVersionFull';
import type { WorkflowVersionStatus } from '../models/WorkflowVersionStatus';

import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';

export class WorkflowVersionService {

    /**
     * Get all versions of a workflow
     * List all versions of a Workflow.
     *
     * Permission "workflow:list" required.
     * @param wid ID of a workflow
     * @param versionStatus Which versions of the workflow to include in the response. Permission 'workflow:list_filter' required if you are not the developer of this workflow. Default PUBLISHED and DEPRECATED
     * @returns WorkflowVersionFull Successful Response
     * @throws ApiError
     */
    public static workflowVersionListWorkflowVersion(
        wid: string,
        versionStatus?: Array<Status>,
    ): CancelablePromise<Array<WorkflowVersionFull>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/{wid}/versions',
            path: {
                'wid': wid,
            },
            query: {
                'version_status': versionStatus,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get a workflow version
     * Get a specific version of a workflow.
     *
     * Permission "workflow:read" required if the version is public or you are the developer of the workflow,
     * otherwise "workflow:read_any"
     * @param gitCommitHash Git commit git_commit_hash of specific version or 'latest'.
     * @param wid ID of a workflow
     * @returns WorkflowVersionFull Successful Response
     * @throws ApiError
     */
    public static workflowVersionGetWorkflowVersion(
        gitCommitHash: string,
        wid: string,
    ): CancelablePromise<WorkflowVersionFull> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/{wid}/versions/{git_commit_hash}',
            path: {
                'git_commit_hash': gitCommitHash,
                'wid': wid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Update status of workflow version
     * Update the status of a workflow version.
     *
     * Permission "workflow:update_status"
     * @param gitCommitHash Git commit git_commit_hash of specific version.
     * @param wid ID of a workflow
     * @param requestBody
     * @returns WorkflowVersionFull Successful Response
     * @throws ApiError
     */
    public static workflowVersionUpdateWorkflowVersionStatus(
        gitCommitHash: string,
        wid: string,
        requestBody: WorkflowVersionStatus,
    ): CancelablePromise<WorkflowVersionFull> {
        return __request(OpenAPI, {
            method: 'PATCH',
            url: '/workflows/{wid}/versions/{git_commit_hash}/status',
            path: {
                'git_commit_hash': gitCommitHash,
                'wid': wid,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

}
